﻿using GrapeCity.Documents.Excel;
using System;
using System.IO;

namespace GcExcel_Performance
{
    class Program
    {
        private static string InputFilePath;

        static Program()
        {
            InputFilePath = Path.Combine("Files", "Input");
        }
        static void Main(string[] args)
        {
            string templateFile = Path.Combine(Directory.GetCurrentDirectory(), "GcExcel-IO-CE-Performance.xlsx");
          
            bool isWindows = System.Runtime.InteropServices.RuntimeInformation.IsOSPlatform(System.Runtime.InteropServices.OSPlatform.Windows);
            bool isMac = System.Runtime.InteropServices.RuntimeInformation.IsOSPlatform(System.Runtime.InteropServices.OSPlatform.OSX);
            bool isLinux = System.Runtime.InteropServices.RuntimeInformation.IsOSPlatform(System.Runtime.InteropServices.OSPlatform.Linux);

            string platform = "unkown";
            if (isWindows)
            {
                platform = "Windows";               
            }
            else if (isMac)
            {
                platform = "MacOS";
            }
            else if (isLinux)
            {
                platform = "Linux";
            }

            string existingResultFile = templateFile.Replace("xlsx", platform + ".xlsx");
            if (File.Exists(existingResultFile))
            {
                templateFile = existingResultFile;
            }

            TestGcExcel(templateFile, platform);
            
            Console.WriteLine("Press Enter to quit...");
            Console.ReadLine();
        }

        private static void TestGcExcel(string templateFile, string platform)
        {
            Workbook workbook = new Workbook();
            workbook.Open(templateFile);
            
            IWorksheet worksheet = workbook.Worksheets[platform];

            double openTime, saveTime, calcTime, memSizeAfterOpen, memSizeAfterCalc;

            string LargeValuesFile = Path.Combine(Directory.GetCurrentDirectory(), InputFilePath, "LargeValues.xlsx");
            GcExcel.Start(LargeValuesFile, out openTime, out saveTime, out calcTime, out memSizeAfterOpen, out memSizeAfterCalc);
            worksheet.Range["C7:G7"].Value = new double[,] { { openTime, saveTime, calcTime, memSizeAfterOpen, memSizeAfterCalc } };

            string LargeFormulasFile = Path.Combine(Directory.GetCurrentDirectory(), InputFilePath, "LargeFormulas.xlsx");
            GcExcel.Start(LargeFormulasFile, out openTime, out saveTime, out calcTime, out memSizeAfterOpen, out memSizeAfterCalc);
            worksheet.Range["C14:G14"].Value = new double[,] { { openTime, saveTime, calcTime, memSizeAfterOpen, memSizeAfterCalc } };

            string ComplexFormulasFile = Path.Combine(Directory.GetCurrentDirectory(), InputFilePath, "ComplexFormulas.xlsx");
            GcExcel.Start(ComplexFormulasFile, out openTime, out saveTime, out calcTime, out memSizeAfterOpen, out memSizeAfterCalc);
            worksheet.Range["C21:G21"].Value = new double[,] { { openTime, saveTime, calcTime, memSizeAfterOpen, memSizeAfterCalc } };

            if (!templateFile.Contains(platform))
            {
                templateFile = templateFile.Replace("xlsx", platform + ".xlsx");
            }
            workbook.Save(templateFile);
        }

    }
}
